@@ -1,6 +1,6 @@
-try:
-    from loguru import logger as log
-except ImportError:
-    pass
+from loguru import logger
+
+log = logger
+
 # log.add('runtime_{time}.log', format="{time} {level} {message}", filter="mootdx", level="INFO", rotation="500 MB")
 # log.add(sys.stdout, filter="mootdx", level="ERROR")
