@@ -1,7 +1,10 @@
 # -*- coding: utf-8 -*-
+from abc import ABC
+
 from pytdx.reader import (BlockReader, CustomerBlockReader, TdxExHqDailyBarReader, TdxLCMinBarReader)
 from unipath import Path
 
+from mootdx import utils
 from mootdx.consts import TYPE_GROUP
 from mootdx.contrib.compat import MooTdxDailyBarReader
 from mootdx.logger import log
@@ -25,7 +28,7 @@ class Reader(object):
             return StdReader(**kwargs)
 
 
-class ReaderBase(object):
+class ReaderBase(ABC):
     """股票市场"""
 
     # 默认通达信安装目录
@@ -61,11 +64,12 @@ class ReaderBase(object):
             ex_ = ex_.strip('.')
             vipdoc = Path(self.tdxdir, 'vipdoc', market, subdir, f'{prefix}{symbol}.{ex_}')
 
-            if Path(vipdoc).exists():
-                log.debug(f"所需的文件: {vipdoc}")
-                return vipdoc
-            else:
+            if not Path(vipdoc).exists():
                 log.debug(f'未找到所需的文件: {vipdoc}')
+                continue
+
+            log.debug(f"找到所需的文件: {vipdoc}")
+            return vipdoc
 
         return None
 
@@ -90,7 +94,7 @@ class StdReader(ReaderBase):
 
     def minute(self, symbol=None, suffix=1):
         """
-        获取1,5分钟线
+        获取1, 5分钟线
 
         :param suffix:
         :param symbol:
@@ -107,9 +111,43 @@ class StdReader(ReaderBase):
         return None
 
     def fzline(self, symbol=None):
+        """
+        分钟线数据
+
+        :param symbol: 自定义板块股票列表, 类型 list
+        :return: pd.dataFrame or Bool
+        """
         return self.minute(symbol, suffix=5)
 
-    def block(self, symbol='block', custom=False, group=False):
+    def block_new(self, name: str = None, symbol: list = None, group=False):
+        """
+        自定义板块数据操作
+        提示: name 和 symbol 全为空则为读取，否则写入操作
+        参考: http://blog.sina.com.cn/s/blog_623d2d280102vt8y.html
+
+        :param name: 自定义板块名称
+        :param symbol: 自定义板块股票列表, 类型 list
+        :param group:
+        :return: pd.dataFrame or Bool
+        """
+
+        if name or symbol:
+            return utils.block_new(self.tdxdir, name=name, symbol=symbol)
+
+        reader = CustomerBlockReader()
+        vipdoc = Path(self.tdxdir, 'T0002', 'blocknew')
+
+        fmt = TYPE_GROUP if group else None
+
+        if Path(vipdoc).isdir():
+            log.debug(f'找到所需的文件: {vipdoc}')
+            return reader.get_df(vipdoc, fmt)
+
+        log.error(f'未找到所需的文件: {vipdoc}')
+
+        return None
+
+    def block(self, symbol='', custom=False, group=False):
         """
         获取板块数据
         参考: http://blog.sina.com.cn/s/blog_623d2d280102vt8y.html
@@ -119,19 +157,21 @@ class StdReader(ReaderBase):
         :param group:
         :return: pd.dataFrame or None
         """
-        if custom:
-            reader = CustomerBlockReader()
-            vipdoc = Path(self.tdxdir, 'T0002', 'blocknew', f'{symbol}')
-        else:
-            reader = BlockReader()
-            vipdoc = Path(self.tdxdir, 'T0002', 'hq_cache', f'{symbol}.dat')
+
+        # suffix = symbol.split('.')
+        # suffix = suffix[-1] if len(suffix) > 1 else 'dat'
+        suffix = 'dat'
+        # symbol = suffix[0]
+
+        reader = BlockReader()
+        vipdoc = Path(self.tdxdir, 'T0002', 'hq_cache', f'{symbol}.{suffix}')
 
         fmt = TYPE_GROUP if group else None
 
         if Path(vipdoc).exists():
             return reader.get_df(vipdoc, fmt)
-        else:
-            log.error('未找到所需的文件: {}'.format(vipdoc))
+
+        log.error(f'未找到所需的文件: {vipdoc}')
 
         return None
 
@@ -139,17 +179,20 @@ class StdReader(ReaderBase):
 class ExtReader(ReaderBase):
     """扩展市场读取"""
 
+    def __init__(self, tdxdir=None):
+        super(ExtReader, self).__init__(tdxdir)
+        self.reader = TdxExHqDailyBarReader()
+
     def daily(self, symbol=None):
         """
         获取扩展市场日线数据
 
         :return: pd.dataFrame or None
         """
-        reader = TdxExHqDailyBarReader()
         vipdoc = self.find_path(symbol=symbol, subdir='lday', suffix='day')
 
         if symbol is not None:
-            return reader.get_df(vipdoc)
+            return self.reader.get_df(vipdoc)
 
         return None
 
@@ -159,11 +202,10 @@ class ExtReader(ReaderBase):
 
         :return: pd.dataFrame or None
         """
-        reader = TdxExHqDailyBarReader()
         vipdoc = self.find_path(symbol=symbol, subdir='minline', suffix='lc1')
 
         if symbol is not None:
-            return reader.get_df(vipdoc)
+            return self.reader.get_df(vipdoc)
 
         return None
 
@@ -173,10 +215,9 @@ class ExtReader(ReaderBase):
 
         :return: pd.dataFrame or None
         """
-        reader = TdxExHqDailyBarReader()
         vipdoc = self.find_path(symbol=symbol, subdir='fzline', suffix='lc5')
 
         if symbol is not None:
-            return reader.get_df(vipdoc)
+            return self.reader.get_df(vipdoc)
 
         return None
